@@ -1,12 +1,11 @@
 import os
 import stat
 from optparse import OptionParser
-import compressor
 import archiver
 
 def parse_args():
     usage = "usage: %prog [options] ppds_directory"
-    version = "%prog 0.1.0\n" \
+    version = "%prog 0.2.0\n" \
               "Copyright (c) 2010 Vitor Baptista.\n" \
               "This is free software; see the source for copying conditions.\n" \
               "There is NO warranty; not even for MERCHANTABILITY or\n" \
@@ -31,7 +30,7 @@ def run():
     (options, args) = parse_args()
     ppds_directory = args[0]
 
-    archive = archiver.create_archive(compressor.compress(ppds_directory))
+    archive = archiver.archive(ppds_directory)
 
     output = open(options.output, "w+")
     output.write(archive)
